# Enverge Proxy

[![PyPI version](https://img.shields.io/pypi/v/enverge_proxy)](https://pypi.org/project/enverge_proxy/)

**Access powerful GPUs with no DevOps or infra configuration inside your current Google Colab notebooks.**

Connects Google Colab with the [Enverge Lab](https://lab.enverge.ai/signup?src=pypi) servers through a proxy, which runs on your local machine.

The proxy routes http://localhost:8123 to GPU-powered Enverge Lab instances.

The proxy should handle all ports, all types of TCP requests and authentication. By default, it uses the HTTPS port 443.

# Requirements

- Python 3.10 and above
- Unix/Windows terminal

# Installation

```bash
pip install enverge_proxy
```

# Getting Started

## Step 1.

After installing the package, please see the docs at [Enverge Lab Colab Proxy](https://lab.enverge.ai/docs/colab-proxy/?source=pypi).

## Step 2.

```
epxy --token <your-enverge-token>
```

# Context

> [Enverge.ai](https://enverge.ai) - Simpler, greener, cheaper AI training platform. 🌱
>
> Enverge harnesses excess green energy for powerful, cost-effective computing on GPUs, enabling environmentally friendly AI model development, training, and fine-tuning. Currently in private alpha with limited spots available.